---
orphan: true
---

# Delaware

> This state uses the Job Center platform. See the [Job Center docs](job_center.md)
> for details on the scraping strategy.

- [Home page](https://joblink.delaware.gov/)
- [Search form](https://joblink.delaware.gov/search/warn_lookups/new)
- [All data][]
- General contact form and regional center phone numbers listed [here](https://joblink.delaware.gov/contact)

[All data]: https://joblink.delaware.gov/search/warn_lookups?commit=Search&page=1&q%5Bemployer_name_cont%5D=&q%5Bmain_contact_contact_info_addresses_full_location_city_matches%5D=&q%5Bnotice_eq%5D=&q%5Bnotice_on_gteq%5D=&q%5Bnotice_on_lteq%5D=&q%5Bs%5D=notice_on+asc&q%5Bservice_delivery_area_id_eq%5D=&q%5Bzipcode_code_start%5D=&utf8=%E2%9C%93
